@@ -9,10 +9,11 @@ class TranslateResult():
     @raw_obfuscated: Raw obfuscated result returned from endpoint if @raw is deobfuscated).
     """
     def __init__(self, translated_text, original_text, original_lang, endpoint, raw, 
-    raw_obfuscated = None, interjection_original = None, interjection_translated = None):
+    raw_obfuscated = None, interjection_original = None, interjection_translated = None, original_lang_score: float = None):
         self.translated_text = translated_text
         self.original_text = original_text
         self.original_lang = original_lang
+        self.original_lang_score = original_lang_score
         self.endpoint = endpoint
         self.interjection_original = interjection_original
         self.interjection_translated = interjection_translated
